/***************************************
	Auteur : Pierre Aubert
	Mail : pierre.aubert@lapp.in2p3.fr
	Licence : CeCILL-C
****************************************/

#include "temporary_alloc.h"
///Allocate temporary
/**	@param[out] tmpInU : Tensor temporary in U
 * 	@param[out] tmpInV : Tensor temporary in V
 * 	@param[out] tmpOutU : Tensor temporary out U
 * 	@param[out] tmpOutV : Tensor temporary out V
 * 	@param nbRow : number of rows of the matrices to be created
 * 	@param nbCol : number of columns of the matrices to be created
*/
void allocate_temporary(std::vector<float> & tmpInU, std::vector<float> & tmpInV, std::vector<float> & tmpOutU, std::vector<float> & tmpOutV,
			size_t nbRow, size_t nbCol)
{
	tmpInU.resize(nbRow*nbCol);
	tmpInV.resize(nbRow*nbCol);
	tmpOutU.resize(nbRow*nbCol);
	tmpOutV.resize(nbRow*nbCol);
	std::fill(tmpInU.begin(), tmpInU.end(), 1.0f);
	std::fill(tmpOutU.begin(), tmpOutU.end(), 1.0f);
	std::fill(tmpInV.begin(), tmpInV.end(), 0.0f);
	std::fill(tmpOutV.begin(), tmpOutV.end(), 0.0f);
	size_t frac(16lu), numBegin(7lu), numEnd(8lu), rowShift(-4lu);
	for(size_t i(rowShift + (numBegin*nbRow)/frac); i < rowShift + (numEnd*nbRow)/frac; ++i){
		for(size_t j((numBegin*nbCol)/frac); j < (numEnd*nbCol)/frac; ++j){
			tmpInU[i*nbCol+ j] = 0.0f;
			tmpInV[i*nbCol+ j] = 1.0f;
		}
	}
}

